@@ -120,7 +120,9 @@ name_lookup <- function(query=NULL, rank=NULL, higherTaxonKey=NULL, status=NULL,
   # hierarchies
   hierdat <- lapply(tt$results, function(x){
     tmp <- x[ names(x) %in% "higherClassificationMap" ]
-    tmpdf <- data.frame(rankkey = names(tmp[[1]]), name = unlist(unname(tmp[[1]])), stringsAsFactors = FALSE)
+    tmpdf <- data.frame(rankkey = names(rgbif_compact(tmp[[1]])),
+                        name = unlist(unname(rgbif_compact(tmp[[1]]))),
+                        stringsAsFactors = FALSE)
     if (NROW(tmpdf) == 0) NULL else tmpdf
   })
   names(hierdat) <- vapply(tt$results, "[[", numeric(1), "key")
