@@ -1,7 +1,9 @@
 context("dataset_search")
 
-tt <- dataset_search(type="OCCURRENCE")
 test_that("type query returns the correct class", {
+  skip_on_cran()
+  
+  tt <- dataset_search(type="OCCURRENCE")
   expect_is(tt, "list")
   expect_is(tt$data, "data.frame")
   expect_is(tt$descriptions, "list")
@@ -9,21 +11,27 @@ test_that("type query returns the correct class", {
 })
 
 # Gets all datasets tagged with keyword "france".
-tt <- dataset_search(keyword="france")
-test_that("keyword query returns the correct class", {
+test_that("keyword query returns the correct", {
+  skip_on_cran()
+  
+  tt <- dataset_search(keyword="france")
+  
+  # class
   expect_is(tt, "list")
   expect_is(tt$data, "data.frame")
   expect_is(tt$data[1,1], "character")
-})
-test_that("keyword query returns the correct value", {
+  
+  # value
   expect_equal(as.character(tt$data$publishingCountry[1]), "FR")
   expect_equal(as.character(tt$data[1,4]), "Tela Botanica")
 })
  
 # Fulltext search for all datasets having the word "amsterdam" somewhere in 
 # its metadata (title, description, etc).
-tt <- dataset_search(query="amsterdam")
 test_that("search query returns the correct class", {
+  skip_on_cran()
+  
+  tt <- dataset_search(query="amsterdam")
   expect_is(tt, "list")
   expect_is(tt$data, "data.frame")
   expect_is(tt$meta, "data.frame")
@@ -33,17 +41,23 @@ test_that("search query returns the correct class", {
 })
 
 # Limited search
-tt <- dataset_search(type="OCCURRENCE", limit=2)
-test_that("limited search returns the correct class", {
+test_that("limited search returns the correct", {
+  skip_on_cran()
+  
+  tt <- dataset_search(type="OCCURRENCE", limit=2)
+  
+  # class
   expect_is(tt$data, "data.frame")
   expect_is(tt$data[1,1], "character")
-})
-test_that("limited search returns the correct dims", {
+  
+  # dims
   expect_equal(dim(tt$data), c(2,8))
 })
  
 # Return just descriptions
-tt <- dataset_search(type="OCCURRENCE", return="descriptions")
 test_that("limited fields query returns the correct class", {
+  skip_on_cran()
+  
+  tt <- dataset_search(type="OCCURRENCE", return="descriptions")
   expect_is(tt, "list")
 })
